==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/ALERTPICKTICKETFIELDMAPPINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ALERTPICKTICKETFIELDMAPPINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ALERTPICKTICKETFIELDMAPPINGID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ALERTID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PICKTICKETFIELD"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTPICKTICKETFIELDMAPPINGID_Type", propOrder = {
    "alertid",
    "pickticketfield"
})
public class ALERTPICKTICKETFIELDMAPPINGID_Type {

    @XmlElement(name = "ALERTID", required = true)
    protected ALERTID_Type alertid;
    @XmlElement(name = "PICKTICKETFIELD", required = true)
    protected String pickticketfield;

    /**
     * Gets the value of the alertid property.
     * 
     * @return
     *     possible object is
     *     {@link ALERTID_Type }
     *     
     */
    public ALERTID_Type getALERTID() {
        return alertid;
    }

    /**
     * Sets the value of the alertid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ALERTID_Type }
     *     
     */
    public void setALERTID(ALERTID_Type value) {
        this.alertid = value;
    }

    /**
     * Gets the value of the pickticketfield property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPICKTICKETFIELD() {
        return pickticketfield;
    }

    /**
     * Sets the value of the pickticketfield property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPICKTICKETFIELD(String value) {
        this.pickticketfield = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_fields/ALERTPICKTICKETFIELDMAPPINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ALERTPICKTICKETFIELDMAPPINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ALERTPICKTICKETFIELDMAPPINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALERTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PICKTICKETFIELD"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTPICKTICKETFIELDMAPPINGID_Type", propOrder = {
    "alertid",
    "pickticketfield"
})
public class ALERTPICKTICKETFIELDMAPPINGID_Type {

    @XmlElement(name = "ALERTID", required = true)
    protected ALERTID_Type alertid;
    @XmlElement(name = "PICKTICKETFIELD", required = true)
    protected String pickticketfield;

    /**
     * Gets the value of the alertid property.
     * 
     * @return
     *     possible object is
     *     {@link ALERTID_Type }
     *     
     */
    public ALERTID_Type getALERTID() {
        return alertid;
    }

    /**
     * Sets the value of the alertid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ALERTID_Type }
     *     
     */
    public void setALERTID(ALERTID_Type value) {
        this.alertid = value;
    }

    /**
     * Gets the value of the pickticketfield property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPICKTICKETFIELD() {
        return pickticketfield;
    }

    /**
     * Sets the value of the pickticketfield property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPICKTICKETFIELD(String value) {
        this.pickticketfield = value;
    }

}
